@@ -32,7 +32,6 @@ class build(ori_build):
                     ('pidname',has_pidname),
                     ('build_ctools', has_ctools),
                     ('build_files', has_files),
-                    ('build_cexe', has_executables),
-                    ('build_ext', has_ext_modules)] \
+                    ('build_cexe', has_executables)] \
                    + ori_build.sub_commands
     
